@@ -1,62 +1,87 @@
 """Sprite, texture and pixel surface routines."""
 import abc
-from ctypes import byref, cast, POINTER, c_int
+from ctypes import byref, cast, POINTER, c_int, c_float
 from .common import SDLError
 from .compat import *
 from .color import convert_to_color
 from .ebs import System
+from .surface import subsurface
 from .window import Window
 from .image import load_image
 from .. import blendmode, surface, rect, video, pixels, render, rwops
 from ..stdinc import Uint8, Uint32
 
 __all__ = ["Sprite", "SoftwareSprite", "TextureSprite", "SpriteFactory",
-           "SoftwareSpriteRenderer", "SpriteRenderer",
-           "TextureSpriteRenderer", "RenderContext", "TEXTURE", "SOFTWARE"]
+           "SoftwareSpriteRenderSystem", "SpriteRenderSystem",
+           "TextureSpriteRenderSystem", "Renderer", "TEXTURE", "SOFTWARE"
+          ]
 
 TEXTURE = 0
 SOFTWARE = 1
 
 
-class RenderContext(object):
-    """SDL2-based rendering context for windows and sprites."""
-    def __init__(self, target, index=-1,
+class Renderer(object):
+    """SDL2-based renderer for windows and sprites."""
+    def __init__(self, target, index=-1, logical_size=None,
                  flags=render.SDL_RENDERER_ACCELERATED):
-        """Creates a new RenderContext for the given target.
+        """Creates a new Renderer for the given target.
 
         If target is a Window or SDL_Window, index and flags are passed
         to the relevant sdl.render.create_renderer() call. If target is
         a SoftwareSprite or SDL_Surface, the index and flags arguments are
         ignored.
         """
-        self.renderer = None
+        self.sdlrenderer = None
         self.rendertaget = None
         if isinstance(target, Window):
-            self.renderer = render.SDL_CreateRenderer(target.window, index,
-                                                      flags)
+            self.sdlrenderer = render.SDL_CreateRenderer(target.window, index,
+                                                         flags)
             self.rendertarget = target.window
         elif isinstance(target, video.SDL_Window):
-            self.renderer = render.SDL_CreateRenderer(target, index, flags)
+            self.sdlrenderer = render.SDL_CreateRenderer(target, index, flags)
             self.rendertarget = target
         elif isinstance(target, SoftwareSprite):
-            self.renderer = render.SDL_CreateSoftwareRenderer(target.surface)
+            self.sdlrenderer = render.SDL_CreateSoftwareRenderer(target.surface)
             self.rendertarget = target.surface
         elif isinstance(target, surface.SDL_Surface):
-            self.renderer = render.SDL_CreateSoftwareRenderer(target)
+            self.sdlrenderer = render.SDL_CreateSoftwareRenderer(target)
             self.rendertarget = target
         else:
             raise TypeError("unsupported target type")
 
+        if logical_size is not None:
+            self.logical_size = logical_size
+
     def __del__(self):
-        if self.renderer:
-            render.SDL_DestroyRenderer(self.renderer)
+        if self.sdlrenderer:
+            render.SDL_DestroyRenderer(self.sdlrenderer)
         self.rendertarget = None
 
+    @property
+    @deprecated
+    def renderer(self):
+        return self.sdlrenderer
+
+    @property
+    def logical_size(self):
+        """The logical pixel size of the Renderer"""
+        w, h = c_int(), c_int()
+        render.SDL_RenderGetLogicalSize(self.sdlrenderer, byref(w), byref(h))
+        return w.value, h.value
+
+    @logical_size.setter
+    def logical_size(self, size):
+        """The logical pixel size of the Renderer"""
+        width, height = size
+        ret = render.SDL_RenderSetLogicalSize(self.sdlrenderer, width, height)
+        if ret != 0:
+            raise SDLError()
+
     @property
     def color(self):
-        """The drawing color of the RenderContext."""
+        """The drawing color of the Renderer."""
         r, g, b, a = Uint8(), Uint8(), Uint8(), Uint8()
-        ret = render.SDL_GetRenderDrawColor(self.renderer, byref(r), byref(g),
+        ret = render.SDL_GetRenderDrawColor(self.sdlrenderer, byref(r), byref(g),
                                             byref(b), byref(a))
         if ret == -1:
             raise SDLError()
@@ -64,9 +89,9 @@ class RenderContext(object):
 
     @color.setter
     def color(self, value):
-        """The drawing color of the RenderContext."""
+        """The drawing color of the Renderer."""
         c = convert_to_color(value)
-        ret = render.SDL_SetRenderDrawColor(self.renderer, c.r, c.g, c.b, c.a)
+        ret = render.SDL_SetRenderDrawColor(self.sdlrenderer, c.r, c.g, c.b, c.a)
         if ret == -1:
             raise SDLError()
 
@@ -74,7 +99,7 @@ class RenderContext(object):
     def blendmode(self):
         """The blend mode used for drawing operations (fill and line)."""
         mode = blendmode.SDL_BlendMode()
-        ret = render.SDL_GetRenderDrawBlendMode(self.renderer, byref(mode))
+        ret = render.SDL_GetRenderDrawBlendMode(self.sdlrenderer, byref(mode))
         if ret == -1:
             raise SDLError()
         return mode
@@ -82,58 +107,77 @@ class RenderContext(object):
     @blendmode.setter
     def blendmode(self, value):
         """The blend mode used for drawing operations (fill and line)."""
-        ret = render.SDL_SetRenderDrawBlendMode(self.renderer, value)
+        ret = render.SDL_SetRenderDrawBlendMode(self.sdlrenderer, value)
         if ret == -1:
             raise SDLError()
 
+    @property
+    def scale(self):
+        """The horizontal and vertical drawing scale."""
+        sx = c_float(0.0)
+        sy = c_float(0.0)
+        render.SDL_RenderGetScale(self.sdlrenderer, byref(sx), byref(sy))
+        return sx.value, sy.value
+
+    @scale.setter
+    def scale(self, value):
+        """The horizontal and vertical drawing scale."""
+        ret = render.SDL_RenderSetScale(self.sdlrenderer, value[0], value[1])
+        if ret != 0:
+            raise SDLError()
+
     def clear(self, color=None):
-        """Clears the rendering context with the currently set or passed
-        color."""
+        """Clears the renderer with the currently set or passed color."""
         if color is not None:
             tmp = self.color
             self.color = color
-        ret = render.SDL_RenderClear(self.renderer)
+        ret = render.SDL_RenderClear(self.sdlrenderer)
         if color is not None:
             self.color = tmp
         if ret == -1:
             raise SDLError()
 
-    def copy(self, src, srcrect=None, dstrect=None):
-        """Copies (blits) the passed source to the target of the
-        RenderContext,"""
-        SDL_Rect = rect.SDL_Rect
+    def copy(self, src, srcrect=None, dstrect=None, angle=0, center=None,
+             flip=render.SDL_FLIP_NONE):
+        """Copies (blits) the passed source to the target of the Renderer."""
         if isinstance(src, TextureSprite):
             texture = src.texture
+            angle = angle or src.angle
+            center = center or src.center
+            flip = flip or src.flip
         elif isinstance(src, render.SDL_Texture):
             texture = src
         else:
             raise TypeError("src must be a TextureSprite or SDL_Texture")
         if srcrect is not None:
             x, y, w, h = srcrect
-            srcrect = SDL_Rect(x, y, w, h)
+            srcrect = rect.SDL_Rect(x, y, w, h)
         if dstrect is not None:
             x, y, w, h = dstrect
-            dstrect = SDL_Rect(x, y, w, h)
-        ret = render.SDL_RenderCopy(self.renderer, texture, srcrect, dstrect)
+            dstrect = rect.SDL_Rect(x, y, w, h)
+        ret = render.SDL_RenderCopyEx(self.sdlrenderer, texture, srcrect,
+                                      dstrect, angle, center, flip)
         if ret == -1:
             raise SDLError()
 
     def present(self):
-        """Refreshes the target of the RenderContext,"""
-        render.SDL_RenderPresent(self.renderer)
+        """Refreshes the target of the Renderer."""
+        render.SDL_RenderPresent(self.sdlrenderer)
 
     def draw_line(self, points, color=None):
-        """Draws one or multiple lines on the rendering context."""
+        """Draws one or multiple connected lines on the renderer."""
         # (x1, y1, x2, y2, ...)
         pcount = len(points)
-        if (pcount % 4) != 0:
+        if (pcount % 2) != 0:
             raise ValueError("points does not contain a valid set of points")
+        if pcount < 4:
+            raise ValueError("points must contain more that one point")
         if pcount == 4:
             if color is not None:
                 tmp = self.color
                 self.color = color
             x1, y1, x2, y2 = points
-            ret = render.SDL_RenderDrawLine(self.renderer, x1, y1, x2, y2)
+            ret = render.SDL_RenderDrawLine(self.sdlrenderer, x1, y1, x2, y2)
             if color is not None:
                 self.color = tmp
             if ret == -1:
@@ -141,8 +185,9 @@ class RenderContext(object):
         else:
             x = 0
             off = 0
+            count = pcount // 2
             SDL_Point = rect.SDL_Point
-            ptlist = (SDL_Point * pcount / 2)()
+            ptlist = (SDL_Point * count)()
             while x < pcount:
                 ptlist[off] = SDL_Point(points[x], points[x + 1])
                 x += 2
@@ -151,14 +196,14 @@ class RenderContext(object):
                 tmp = self.color
                 self.color = color
             ptr = cast(ptlist, POINTER(SDL_Point))
-            ret = render.SDL_RenderDrawLines(self.renderer, ptr, pcount / 2)
+            ret = render.SDL_RenderDrawLines(self.sdlrenderer, ptr, count)
             if color is not None:
                 self.color = tmp
             if ret == -1:
                 raise SDLError()
 
     def draw_point(self, points, color=None):
-        """Draws one or multiple points on the rendering context."""
+        """Draws one or multiple points on the renderer."""
         # (x1, y1, x2, y2, ...)
         pcount = len(points)
         if (pcount % 2) != 0:
@@ -167,7 +212,7 @@ class RenderContext(object):
             if color is not None:
                 tmp = self.color
                 self.color = color
-            ret = render.SDL_RenderDrawPoint(self.renderer, points[0],
+            ret = render.SDL_RenderDrawPoint(self.sdlrenderer, points[0],
                                              points[1])
             if color is not None:
                 self.color = tmp
@@ -176,8 +221,9 @@ class RenderContext(object):
         else:
             x = 0
             off = 0
+            count = pcount // 2
             SDL_Point = rect.SDL_Point
-            ptlist = (SDL_Point * pcount / 2)()
+            ptlist = (SDL_Point * count)()
             while x < pcount:
                 ptlist[off] = SDL_Point(points[x], points[x + 1])
                 x += 2
@@ -186,14 +232,14 @@ class RenderContext(object):
                 tmp = self.color
                 self.color = color
             ptr = cast(ptlist, POINTER(SDL_Point))
-            ret = render.SDL_RenderDrawPoints(self.renderer, ptr)
+            ret = render.SDL_RenderDrawPoints(self.sdlrenderer, ptr, count)
             if color is not None:
                 self.color = tmp
             if ret == -1:
                 raise SDLError()
 
     def draw_rect(self, rects, color=None):
-        """Draws one or multiple rectangles on the rendering context."""
+        """Draws one or multiple rectangles on the renderer."""
         SDL_Rect = rect.SDL_Rect
         # ((x, y, w, h), ...)
         if type(rects[0]) == int:
@@ -202,7 +248,7 @@ class RenderContext(object):
                 tmp = self.color
                 self.color = color
             x, y, w, h = rects
-            ret = render.SDL_RenderDrawRect(self.renderer, SDL_Rect(x, y, w, h))
+            ret = render.SDL_RenderDrawRect(self.sdlrenderer, SDL_Rect(x, y, w, h))
             if color is not None:
                 self.color = tmp
             if ret == -1:
@@ -215,16 +261,15 @@ class RenderContext(object):
             if color is not None:
                 tmp = self.color
                 self.color = color
-            ptr = cast(rlist, SDL_Rect)
-            ret = render.SDL_RenderDrawRects(self.renderer, ptr)
+            ptr = cast(rlist, POINTER(SDL_Rect))
+            ret = render.SDL_RenderDrawRects(self.sdlrenderer, ptr, len(rects))
             if color is not None:
                 self.color = tmp
             if ret == -1:
                 raise SDLError()
 
     def fill(self, rects, color=None):
-        """Fills one or multiple rectangular areas on the rendering
-        context."""
+        """Fills one or multiple rectangular areas on the renderer."""
         SDL_Rect = rect.SDL_Rect
         # ((x, y, w, h), ...)
         if type(rects[0]) == int:
@@ -233,7 +278,7 @@ class RenderContext(object):
                 tmp = self.color
                 self.color = color
             x, y, w, h = rects
-            ret = render.SDL_RenderFillRect(self.renderer, SDL_Rect(x, y, w, h))
+            ret = render.SDL_RenderFillRect(self.sdlrenderer, SDL_Rect(x, y, w, h))
             if color is not None:
                 self.color = tmp
             if ret == -1:
@@ -246,14 +291,15 @@ class RenderContext(object):
             if color is not None:
                 tmp = self.color
                 self.color = color
-            ptr = cast(rlist, SDL_Rect)
-            ret = render.SDL_RenderFillRects(self.renderer, ptr)
+            ptr = cast(rlist, POINTER(SDL_Rect))
+            ret = render.SDL_RenderFillRects(self.sdlrenderer, ptr, len(rects))
             if color is not None:
                 self.color = tmp
             if ret == -1:
                 raise SDLError()
 
 
+
 class Sprite(object):
     """A simple 2D object."""
     __metaclass__ = abc.ABCMeta
@@ -313,6 +359,19 @@ class SoftwareSprite(Sprite):
         """The size of the SoftwareSprite as tuple."""
         return self.surface.w, self.surface.h
 
+    def subsprite(self, area):
+        """Creates another SoftwareSprite from a part of the SoftwareSprite.
+
+        The two sprites share pixel data, so if the parent sprite's surface is
+        not managed by the sprite (free is False), you will need to keep it
+        alive while the subsprite exists."""
+        ssurface = subsurface(self.surface, area)
+        ssprite = SoftwareSprite(ssurface, True)
+        # Keeps the parent surface alive until subsprite is freed
+        if self.free:
+            ssprite._parent = self
+        return ssprite
+
     def __repr__(self):
         return "SoftwareSprite(size=%s, bpp=%d)" % \
             (self.size, self.surface.format.contents.BitsPerPixel)
@@ -332,7 +391,10 @@ class TextureSprite(Sprite):
                                       byref(w), byref(h))
         if ret == -1:
             raise SDLError()
+        self.angle = 0.0
+        self.flip = render.SDL_FLIP_NONE
         self._size = w.value, h.value
+        self._center = None
 
     def __del__(self):
         """Releases the bound SDL_Texture."""
@@ -340,6 +402,19 @@ class TextureSprite(Sprite):
             render.SDL_DestroyTexture(self.texture)
         self.texture = None
 
+    @property
+    def center(self):
+        """The center of the TextureSprite as tuple."""
+        return self._center
+
+    @center.setter
+    def center(self, value):
+        """Sets the center of the TextureSprite."""
+        if value != None:
+            self._center = rect.SDL_Point(value[0], value[1])
+        else:
+            self._center = None
+
     @property
     def size(self):
         """The size of the TextureSprite as tuple."""
@@ -354,8 +429,9 @@ class TextureSprite(Sprite):
                                       byref(access), byref(w), byref(h))
         if ret == -1:
             raise SDLError()
-        return "TextureSprite(format=%d, access=%d, size=%s)" % \
-            (flags.value, access.value, (w.value, h.value))
+        return "TextureSprite(format=%d, access=%d, size=%s, angle=%f, center=%s)" % \
+            (flags.value, access.value, (w.value, h.value), self.angle,
+             (self.center.x, self.center.y))
 
 
 class SpriteFactory(object):
@@ -371,9 +447,9 @@ class SpriteFactory(object):
         """
         if sprite_type == TEXTURE:
             if "renderer" not in kwargs:
-                raise ValueError("you have to provide a renderer= argument")
+                raise ValueError("you have to provide a renderer=<arg> argument")
         elif sprite_type != SOFTWARE:
-            raise ValueError("stype must be TEXTURE or SOFTWARE")
+            raise ValueError("sprite_type must be TEXTURE or SOFTWARE")
         self._spritetype = sprite_type
         self.default_args = kwargs
 
@@ -389,16 +465,16 @@ class SpriteFactory(object):
         return "SpriteFactory(sprite_type=%s, default_args=%s)" % \
             (stype, self.default_args)
 
-    def create_sprite_renderer(self, *args, **kwargs):
-        """Creates a new SpriteRenderer.
+    def create_sprite_render_system(self, *args, **kwargs):
+        """Creates a new SpriteRenderSystem.
 
         For TEXTURE mode, the passed args and kwargs are ignored and the
-        RenderContext or SDL_Renderer passed to the SpriteFactory is used.
+        Renderer or SDL_Renderer passed to the SpriteFactory is used.
         """
         if self.sprite_type == TEXTURE:
-            return TextureSpriteRenderer(self.default_args["renderer"])
+            return TextureSpriteRenderSystem(self.default_args["renderer"])
         else:
-            return SoftwareSpriteRenderer(*args, **kwargs)
+            return SoftwareSpriteRenderSystem(*args, **kwargs)
 
     def from_image(self, fname):
         """Creates a Sprite from the passed image file."""
@@ -412,16 +488,17 @@ class SpriteFactory(object):
         """
         if self.sprite_type == TEXTURE:
             renderer = self.default_args["renderer"]
-            texture = render.SDL_CreateTextureFromSurface(renderer.renderer,
+            texture = render.SDL_CreateTextureFromSurface(renderer.sdlrenderer,
                                                           tsurface)
             if not texture:
                 raise SDLError()
-            s = TextureSprite(texture.contents)
+            sprite = TextureSprite(texture.contents)
             if free:
                 surface.SDL_FreeSurface(tsurface)
+            return sprite
         elif self.sprite_type == SOFTWARE:
-            s = SoftwareSprite(tsurface, free)
-        return s
+            return SoftwareSprite(tsurface, free)
+        raise ValueError("sprite_type must be TEXTURE or SOFTWARE")
 
     def from_object(self, obj):
         """Creates a Sprite from an arbitrary object."""
@@ -431,14 +508,14 @@ class SpriteFactory(object):
             imgsurface = surface.SDL_LoadBMP_RW(rw, True)
             if not imgsurface:
                 raise SDLError()
-            s = self.from_surface(imgsurface.contents, True)
+            return self.from_surface(imgsurface.contents, True)
         elif self.sprite_type == SOFTWARE:
             rw = rwops.rw_from_object(obj)
             imgsurface = surface.SDL_LoadBMP_RW(rw, True)
             if not imgsurface:
                 raise SDLError()
-            s = SoftwareSprite(imgsurface.contents, True)
-        return s
+            return SoftwareSprite(imgsurface.contents, True)
+        raise ValueError("sprite_type must be TEXTURE or SOFTWARE")
 
     def from_color(self, color, size, bpp=32, masks=None):
         """Creates a sprite with a certain color.
@@ -448,29 +525,29 @@ class SpriteFactory(object):
             rmask, gmask, bmask, amask = masks
         else:
             rmask = gmask = bmask = amask = 0
-        sf = surface.SDL_CreateRGBSurface(0, size[0], size[1], bpp, rmask,
-                                          gmask, bmask, amask)
-        if not sf:
+        sfc = surface.SDL_CreateRGBSurface(0, size[0], size[1], bpp, rmask,
+                                           gmask, bmask, amask)
+        if not sfc:
             raise SDLError()
-        sf = sf.contents
-        fmt = sf.format.contents
+        sfc = sfc.contents
+        fmt = sfc.format.contents
         if fmt.Amask != 0:
             # Target has an alpha mask
-            c = pixels.SDL_MapRGBA(fmt, color.r, color.g, color.b, color.a)
+            col = pixels.SDL_MapRGBA(fmt, color.r, color.g, color.b, color.a)
         else:
-            c = pixels.SDL_MapRGB(fmt, color.r, color.g, color.b)
-        ret = surface.SDL_FillRect(sf, None, c)
+            col = pixels.SDL_MapRGB(fmt, color.r, color.g, color.b)
+        ret = surface.SDL_FillRect(sfc, None, col)
         if ret == -1:
             raise SDLError()
-        return self.from_surface(sf, True)
+        return self.from_surface(sfc, True)
 
     def from_text(self, text, **kwargs):
         """Creates a Sprite from a string of text."""
         args = self.default_args.copy()
         args.update(kwargs)
         fontmanager = args['fontmanager']
-        surface = fontmanager.render(text, **args)
-        return self.from_surface(surface, free=True)
+        sfc = fontmanager.render(text, **args)
+        return self.from_surface(sfc, free=True)
 
     def create_sprite(self, **kwargs):
         """Creates an empty Sprite.
@@ -520,8 +597,8 @@ class SpriteFactory(object):
         """
         if isinstance(renderer, render.SDL_Renderer):
             sdlrenderer = renderer
-        elif isinstance(renderer, RenderContext):
-            sdlrenderer = renderer.renderer
+        elif isinstance(renderer, Renderer):
+            sdlrenderer = renderer.sdlrenderer
         else:
             raise TypeError("renderer must be a Renderer or SDL_Renderer")
         texture = render.SDL_CreateTexture(sdlrenderer, pformat, access,
@@ -531,7 +608,7 @@ class SpriteFactory(object):
         return TextureSprite(texture.contents)
 
 
-class SpriteRenderer(System):
+class SpriteRenderSystem(System):
     """A rendering system for Sprite components.
 
     This is a base class for rendering systems capable of drawing and
@@ -540,11 +617,11 @@ class SpriteRenderer(System):
     method.
     """
     def __init__(self):
-        super(SpriteRenderer, self).__init__()
+        super(SpriteRenderSystem, self).__init__()
         self.componenttypes = (Sprite,)
         self._sortfunc = lambda e: e.depth
 
-    def render(self, sprites):
+    def render(self, sprites, x=None, y=None):
         """Renders the passed sprites.
 
         This is a no-op function and needs to be implemented by inheriting
@@ -579,39 +656,39 @@ class SpriteRenderer(System):
         self._sortfunc = value
 
 
-class SoftwareSpriteRenderer(SpriteRenderer):
+class SoftwareSpriteRenderSystem(SpriteRenderSystem):
     """A rendering system for SoftwareSprite components.
 
-    The SoftwareSpriteRenderer class uses a Window as drawing device to
+    The SoftwareSpriteRenderSystem class uses a Window as drawing device to
     display Sprite surfaces. It uses the Window's internal SDL surface as
     drawing context, so that GL operations, such as texture handling or
     using SDL renderers is not possible.
     """
     def __init__(self, window):
-        """Creates a new SoftSpriteRenderer for a specific Window."""
-        super(SoftwareSpriteRenderer, self).__init__()
+        """Creates a new SoftwareSpriteRenderSystem for a specific Window."""
+        super(SoftwareSpriteRenderSystem, self).__init__()
         if isinstance(window, Window):
             self.window = window.window
         elif isinstance(window, video.SDL_Window):
             self.window = window
         else:
             raise TypeError("unsupported window type")
-        surface = video.SDL_GetWindowSurface(self.window)
-        if not surface:
+        sfc = video.SDL_GetWindowSurface(self.window)
+        if not sfc:
             raise SDLError()
-        self.surface = surface.contents
+        self.surface = sfc.contents
         self.componenttypes = (SoftwareSprite,)
 
     def render(self, sprites, x=None, y=None):
         """Draws the passed sprites (or sprite) on the Window's surface.
 
-        x and y are optional arguments that can be used as relative
-        drawing location for sprites. If set to None, the location
-        information of the sprites are used. If set and sprites is an
-        iterable, such as a list of SoftwareSprite objects, x and y are
-        relative location values that will be added to each individual sprite's
-        position. If sprites is a single SoftwareSprite, x and y denote the
-        absolute position of the SoftwareSprite, if set.
+        x and y are optional arguments that can be used as relative drawing
+        location for sprites. If set to None, the location information of the
+        sprites are used. If set and sprites is an iterable, such as a list of
+        SoftwareSprite objects, x and y are relative location values that will
+        be added to each individual sprite's position. If sprites is a single
+        SoftwareSprite, x and y denote the absolute position of the
+        SoftwareSprite, if set.
         """
         r = rect.SDL_Rect(0, 0, 0, 0)
         if isiterable(sprites):
@@ -619,10 +696,10 @@ class SoftwareSpriteRenderer(SpriteRenderer):
             imgsurface = self.surface
             x = x or 0
             y = y or 0
-            for sp in sprites:
-                r.x = x + sp.x
-                r.y = y + sp.y
-                blit_surface(sp.surface, None, imgsurface, r)
+            for sprite in sprites:
+                r.x = x + sprite.x
+                r.y = y + sprite.y
+                blit_surface(sprite.surface, None, imgsurface, r)
         else:
             r.x = sprites.x
             r.y = sprites.y
@@ -633,27 +710,26 @@ class SoftwareSpriteRenderer(SpriteRenderer):
         video.SDL_UpdateWindowSurface(self.window)
 
 
-class TextureSpriteRenderer(SpriteRenderer):
+class TextureSpriteRenderSystem(SpriteRenderSystem):
     """A rendering system for TextureSprite components.
 
-    The TextureSpriteRenderer class uses a SDL_Renderer as drawing
+    The TextureSpriteRenderSystem class uses a SDL_Renderer as drawing
     device to display TextureSprite objects.
     """
     def __init__(self, target):
-        """Creates a new TextureSpriteRenderer.
+        """Creates a new TextureSpriteRenderSystem.
 
-        target can be a Window, SDL_Window, RenderContext or SDL_Renderer.
-        If it is a Window or SDL_Window instance, a RenderContext will be
+        target can be a Window, SDL_Window, Renderer or SDL_Renderer.
+        If it is a Window or SDL_Window instance, a Renderer will be
         created to acquire the SDL_Renderer.
         """
-        super(TextureSpriteRenderer, self).__init__()
+        super(TextureSpriteRenderSystem, self).__init__()
         if isinstance(target, (Window, video.SDL_Window)):
             # Create a Renderer for the window and use that one.
-            target = RenderContext(target)
-
-        if isinstance(target, RenderContext):
+            target = Renderer(target)
+        if isinstance(target, Renderer):
             self._renderer = target  # Used to prevent GC
-            sdlrenderer = target.renderer
+            sdlrenderer = target.sdlrenderer
         elif isinstance(target, render.SDL_Renderer):
             sdlrenderer = target
         else:
@@ -673,16 +749,17 @@ class TextureSpriteRenderer(SpriteRenderer):
         denote the absolute position of the TextureSprite, if set.
         """
         r = rect.SDL_Rect(0, 0, 0, 0)
+        rcopy = render.SDL_RenderCopyEx
         if isiterable(sprites):
-            rcopy = render.SDL_RenderCopy
             renderer = self.sdlrenderer
             x = x or 0
             y = y or 0
-            for sp in sprites:
-                r.x = x + sp.x
-                r.y = y + sp.y
-                r.w, r.h = sp.size
-                if rcopy(renderer, sp.texture, None, r) == -1:
+            for sprite in sprites:
+                r.x = x + sprite.x
+                r.y = y + sprite.y
+                r.w, r.h = sprite.size
+                if rcopy(renderer, sprite.texture, None, r, sprite.angle,
+                         sprite.center, sprite.flip) == -1:
                     raise SDLError()
         else:
             r.x = sprites.x
@@ -691,5 +768,7 @@ class TextureSpriteRenderer(SpriteRenderer):
             if x is not None and y is not None:
                 r.x = x
                 r.y = y
-            render.SDL_RenderCopy(self.sdlrenderer, sprites.texture, None, r)
+            if rcopy(self.sdlrenderer, sprites.texture, None, r, sprites.angle,
+                     sprites.center, sprites.flip) == -1:
+                raise SDLError()
         render.SDL_RenderPresent(self.sdlrenderer)
