@@ -8,7 +8,7 @@ from .video import SDL_Window
 __all__ = ["SDL_SYSWM_TYPE", "SDL_SYSWM_UNKNOWN", "SDL_SYSWM_WINDOWS",
            "SDL_SYSWM_X11", "SDL_SYSWM_DIRECTFB", "SDL_SYSWM_COCOA",
            "SDL_SYSWM_UIKIT", "SDL_SYSWM_WAYLAND", "SDL_SYSWM_MIR",
-           "SDL_SYSWM_WINRT", "SDL_SYSWM_ANDROID",
+           "SDL_SYSWM_WINRT", "SDL_SYSWM_ANDROID", "SDL_SYSWM_VIVANTE",
            "SDL_SysWMmsg", "SDL_SysWMinfo", "SDL_GetWindowWMInfo"
            ]
 
@@ -23,6 +23,7 @@ SDL_SYSWM_WAYLAND = 6
 SDL_SYSWM_MIR = 7
 SDL_SYSWM_WINRT = 8
 SDL_SYSWM_ANDROID = 9
+SDL_SYSWM_VIVANTE = 10
 
 # FIXME: Hack around the ctypes "_type_ 'v' not supported" bug - remove
 # once this has been fixed properly in Python 2.7+
@@ -132,6 +133,11 @@ class _android(Structure):
                 ("surface", c_void_p)]
 
 
+class _vivante(Structure):
+    """Window information for Vivante."""
+    _fields_ = [("display", c_void_p),
+                ("window", c_void_p)]
+
 class _info(Union):
     """The platform-specific information of a window."""
     _fields_ = [("win", _wininfo),
@@ -143,6 +149,7 @@ class _info(Union):
                 ("wl", _wl),
                 ("mir", _mir),
                 ("android", _android),
+                ("vivante", _vivante),
                 ("dummy", c_int)
                 ]
 
