@@ -251,7 +251,7 @@ class SDLAudioTest(unittest.TestCase):
         pass
 
     @unittest.skip("not implemented")
-    def test_SDL_PausAudio(self):
+    def test_SDL_PauseAudio(self):
         pass
 
     @unittest.skip("not implemented")
@@ -310,6 +310,10 @@ class SDLAudioTest(unittest.TestCase):
     def test_SDL_ClearQueuedAudio(self):
         pass
 
+    @unittest.skip("not implemented")
+    def test_SDL_DequeueAudio(self):
+        pass
+
 
 if __name__ == '__main__':
     sys.exit(unittest.main())
